### package.json 其他配置

```sh
# files: 指定发布的文件，其他的不发布
"files": []

# repository 指定git信息
"repository": {
  "type": "git",
  "url": "git+https://github.com/xxx/xxx.git"
}
```

### npm 发包

发包到npm官方仓库：

```sh
# https://www.npmjs.com 注册账号
# 登录npm，然后输入账号密码和邮箱信息
npm login

# 发布到npm官方仓库
npm publish

# version 每次发布都修改版本号，否则会报错
```

### 为什么要使用 npm 私服

- 提升下载速度 （局域网）
- 保证版本一致性
- 保证安全 （防止npm上的依赖包被删除）
- 控制依赖版本
- 方便内部使用

### 搭建本地 npm 私服（Verdaccio 服务器）

```sh
# 安装
npm install -g verdaccio

# 启动
verdaccio --listen 9999

# 访问 http://localhost:9999/

# 创建用户
# 不使用后缀：直接adduser则是在当前源下创建用户，使用--registry则是在指定的源下创建用户
npm adduser --registry http://localhost:9999
```

### 修订版本号并发布 standard-version

```sh
# 安装
npm install -g standard-version

# 根据提交的commit信息来自动更新版本号和生成更新日志，会给提交打上版本标签并生成changelog文件
standard-version

# 如果有远程仓库：提交到远程仓库并提交标签信息
git push --follow-tags origin main

# 发布到npm私服（http://localhost:9999: 本地 verdaccio 搭建的npm私服）
npm publish --registry http://localhost:9999
```

### 修订版本号 其他方法

```sh
# 使用npm命令自增修订版本号（第一位）：
npm version patch

# 使用npm命令自增修订版本号（第二位）：
npm version minor

# 使用npm命令自增修订版本号（第三位）：
npm version major

# 如果想要在发布之前自动更新版本号，可以在package.json中的scripts字段添加一个发布脚本，并在发布脚本中使用npm version命令。
"scripts": {
  "release": "npm version patch && npm publish"
}
```

### 指定项目发包的源地址

方法一：package.json（优先级更高）
```sh
"publishConfig": {
  "registry": "http://localhost:9999"
}
```
方法二：.npmrc文件
```sh
registry=http://localhost:9999
```

### 使用 nrm 工具来管理和切换不同的 npm 源

nrm用于切换全局的npm源，会被项目中配置的npm源所覆盖。
```sh
# 安装
npm install -g nrm

# 查看可用的源
nrm ls

# 切换源
nrm use <源名称>

# 添加源
nrm add <源名称> <源地址>

# 删除源
nrm del <源名称>
```

### 常用命令

```sh
# 查看npm配置信息：-g查看全局，-l查看详细信息
npm config ls [-g] [-l]

# 查看npm源
npm config get registry

# 设置npm源
npm config set registry <源地址>

# 查看npm当前用户名
npm whoami
npm who am i

# 设置npm当前用户名
npm set init-author-name <用户名>

# 设置npm当前用户邮箱
npm set init-author-email <邮箱>

# 设置npm当前用户主页 
npm set init-author-url <用户主页>
```